Package 'angstromATE'
| Title: |
Imports Recipe and Log Files from Angstrom Engineering Thermal
Evaporator |
| Description: |
Package for importing recipe and log files generated by
Angstrom Engineering thermal evaporator systems. These recipe
and log files contain detailed time-series records of chamber
pressure, source activity, deposition rate, film thickness,
tooling parameters, substrate conditions, and other process
variables. `angstromATE` extracts the most useful information
from these files and returns it in a compact, analysis-ready
format. |
| Authors: |
Thomas Gredig [aut, cre, cph]
 |
| Maintainer: |
Thomas Gredig <[email protected]> |
| License: |
GPL (>= 3) |
| Version: |
0.2.1 |
| Built: |
2026-05-18 23:36:11 UTC |
| Source: |
https://github.com/thomasgredig/angstromate |
Help Index